==> totvs-log-web-foundation-0.0.9.tgz: package/src/lib/services/auth/auth.service.ts <==
import { Router, NavigationStart } from '@angular/router';
import { Injectable, Inject } from '@angular/core';
import {
    AuthBaseService,
    AuthHandlerType,
    AUTH_SETTINGS,
    IAuthSettings,
    AUTH_TYPE,
    IAuthHandlerType,
    CriticalError
} from 'totvs-log-base-foundation';
import { User } from 'oidc-client';
import { ThfToolbarProfile } from '@totvs/thf-ui';

@Injectable()
/**
 * Classe de serviço com métodos para autenticação
 * @extends AuthBaseService
 */
export class AuthService extends AuthBaseService {

    /**
     * Método construtor da classe
     * @param authSettings Token de injeção com as configurações de autenticação
     * @param authType Token de injeção com o tipo de autenticação
     */
    constructor(@Inject(AUTH_SETTINGS) private authSettings: IAuthSettings,
                @Inject(AUTH_TYPE) private authType: IAuthHandlerType) {
        super(AuthService.AddOriginUrls(authSettings));
        if (this.authSettings === undefined) {
            throw new CriticalError('authSettings: undefined');
        }
        if (this.authType === undefined) {
            throw new CriticalError('authType: undefined');
        }
    }
    /**
     * Adiciona nas uris de redirecionamento do processo oauth o host de origem, se um host não for informado
     * Isso é para permitir que o navegador identifique o domínio de redirecionamento
     * utilizando o caminho relativo
     *
     * @param authSettings as configurações de autenticação
     * @returns as configurações de autenticação com uris normalizadas para o processo de autenticação
     */
    public static AddOriginUrls(authSettings: IAuthSettings): IAuthSettings {
        if (authSettings) {

            authSettings.redirect_uri = AuthService.AddOriginUrl(window.location.origin, authSettings.redirect_uri );

            authSettings.post_logout_redirect_uri
             = AuthService.AddOriginUrl(window.location.origin, authSettings.post_logout_redirect_uri );

            authSettings.silent_redirect_uri = AuthService.AddOriginUrl(window.location.origin, authSettings.silent_redirect_uri );

            if (!authSettings.post_logout_redirect_uri) {
                authSettings.post_logout_redirect_uri = window.location.origin;
            }
        }
        return authSettings;
    }
    /**
     * Adiciona o host na url, se nenhum host estiver presente
     * @param host o host a ser adicionado
     * @param url url em que o host será adicionado
     * @returns a junção da url e host
     */
    public static AddOriginUrl(host: string, url: string): string {
        if (url.trim().length !== 0 && !url.startsWith(host) && !url.startsWith('http')) {
            url = `${host}${url}`;
        }
        return url;
    }
    /**
     * Verifica se está em atuação o fluxo de login e deveria ou não mostrar o menu
     */
    public shouldShowMenu(router: Router): boolean {
        let loginFlow = false;
        router.events.forEach((event) => {
            if (event instanceof NavigationStart) {
                loginFlow = event.url === '' || event.url === '/' || event.url.startsWith('/auth-callback');
                // vai redirecionar, guarda a rota atual
                if (!loginFlow) {
                  localStorage.setItem('current.route', event.url);
                }
            }
        });
        return loginFlow;
    }
    /**
     * Monta um ThfToolbarProfile a partir do usuário. Sem suporte a avatar no momento
     */
    public getToolbarProfile(user: User): ThfToolbarProfile {
        return {
            title : user && user.profile ? user.profile.name : null,
            subtitle : user && user.profile ? user.profile.email : null
        };
    }
    /**
     * Método responsável executar o processo de login/autenticação
     */
    public async loginFlow(): Promise<void> {
        if (this.authType.type === AuthHandlerType.oauth2) {
          await this.signinRedirect();
        }
    }
    /**
     * Método responsável executar o processo de logout
     */
    public async logoutFlow(): Promise<void> {
        if (this.authType.type === AuthHandlerType.oauth2) {
           await this.signoutRedirect();
        }
    }
}

==> totvs-log-web-foundation-1.0.0.tgz: package/src/lib/services/auth/auth.service.ts <==
import { Router, NavigationStart } from '@angular/router';
import { Injectable, Inject } from '@angular/core';
import {
    AuthBaseService,
    AuthHandlerType,
    AUTH_SETTINGS,
    IAuthSettings,
    AUTH_TYPE,
    IAuthHandlerType,
    CriticalError
} from 'totvs-log-base-foundation';
import { User } from 'oidc-client';
import { PoToolbarProfile } from '@portinari/portinari-ui';

@Injectable()
/**
 * Classe de serviço com métodos para autenticação
 * @extends AuthBaseService
 */
export class AuthService extends AuthBaseService {

    /**
     * Método construtor da classe
     * @param authSettings Token de injeção com as configurações de autenticação
     * @param authType Token de injeção com o tipo de autenticação
     */
    constructor(@Inject(AUTH_SETTINGS) private authSettings: IAuthSettings,
                @Inject(AUTH_TYPE) private authType: IAuthHandlerType) {
        super(AuthService.AddOriginUrls(authSettings));
        if (this.authSettings === undefined) {
            throw new CriticalError('authSettings: undefined');
        }
        if (this.authType === undefined) {
            throw new CriticalError('authType: undefined');
        }
    }
    /**
     * Adiciona nas uris de redirecionamento do processo oauth o host de origem, se um host não for informado
     * Isso é para permitir que o navegador identifique o domínio de redirecionamento
     * utilizando o caminho relativo
     *
     * @param authSettings as configurações de autenticação
     * @returns as configurações de autenticação com uris normalizadas para o processo de autenticação
     */
    public static AddOriginUrls(authSettings: IAuthSettings): IAuthSettings {
        if (authSettings) {

            authSettings.redirect_uri = AuthService.AddOriginUrl(window.location.origin, authSettings.redirect_uri );

            authSettings.post_logout_redirect_uri
             = AuthService.AddOriginUrl(window.location.origin, authSettings.post_logout_redirect_uri );

            authSettings.silent_redirect_uri = AuthService.AddOriginUrl(window.location.origin, authSettings.silent_redirect_uri );

            if (!authSettings.post_logout_redirect_uri) {
                authSettings.post_logout_redirect_uri = window.location.origin;
            }
        }
        return authSettings;
    }
    /**
     * Adiciona o host na url, se nenhum host estiver presente
     * @param host o host a ser adicionado
     * @param url url em que o host será adicionado
     * @returns a junção da url e host
     */
    public static AddOriginUrl(host: string, url: string): string {
        if (url.trim().length !== 0 && !url.startsWith(host) && !url.startsWith('http')) {
            url = `${host}${url}`;
        }
        return url;
    }
    /**
     * Verifica se está em atuação o fluxo de login e deveria ou não mostrar o menu
     */
    public shouldShowMenu(router: Router): boolean {
        let loginFlow = false;
        router.events.forEach((event) => {
            if (event instanceof NavigationStart) {
                loginFlow = event.url === '' || event.url === '/' || event.url.startsWith('/auth-callback');
                // vai redirecionar, guarda a rota atual
                if (!loginFlow) {
                  localStorage.setItem('current.route', event.url);
                }
            }
        });
        return loginFlow;
    }
    /**
     * Monta um PoToolbarProfile a partir do usuário. Sem suporte a avatar no momento
     */
    public getToolbarProfile(user: User): PoToolbarProfile {
        return {
            title : user && user.profile ? user.profile.name : null,
            subtitle : user && user.profile ? user.profile.email : null
        };
    }
    /**
     * Método responsável executar o processo de login/autenticação
     */
    public async loginFlow(): Promise<void> {
        if (this.authType.type === AuthHandlerType.oauth2) {
          await this.signinRedirect();
        }
    }
    /**
     * Método responsável executar o processo de logout
     */
    public async logoutFlow(): Promise<void> {
        if (this.authType.type === AuthHandlerType.oauth2) {
           await this.signoutRedirect();
        }
    }
}
